==> nui_core-0.0.127.tar.gz: lib/ui/component/nui_state_widget.dart <==
import 'package:flutter/cupertino.dart';

bool updateNUIState<T>({@required String id, @required T update}){
  return _NUIStateCache.updateCache<T>(id, update);
}

class _NUIStateCache{
  static Map<String, _NUIState> cache = Map();

  static void addToCache<T>(String id, _NUIState<T> state){
    cache[id] = state;
  }

  static void removeFromCache<T>(String id){
    cache.remove(id);
  }

  static bool updateCache<T>(String id, T update){
    final item = getFromCache<T>(id);
    if(item != null){
      item._refresh(update);
      return true;
    }
    return false;
  }

  static _NUIState<T> getFromCache<T>(String id){
    final cacheItem = cache[id];
    if(cacheItem is _NUIState<T>){
      return cacheItem;
    }
    return null;
  }
}

typedef NUIStateUIListener<T> = Widget Function(T data);
class NUIStateful<T> extends StatefulWidget {
  NUIStateful({@required this.id, @required this.child, @required this.initial});
  final NUIStateUIListener<T> child;
  final T initial;
  final String id;
  @override
  _NUIState<T> createState() => _NUIState<T>();
}

class _NUIState<T> extends State<NUIStateful<T>> {
  T data;

  @override
  void initState(){
    super.initState();
    data = widget.initial;
    _NUIStateCache.addToCache<T>(widget.id, this);
  }

  @override
  Widget build(BuildContext context) {
    return widget.child(data);
  }

  @override
  void dispose(){
    super.dispose();
    _NUIStateCache.removeFromCache<T>(widget.id);
  }

  void _refresh(T update){
    setState(() {
      data = update;
    });
  }
}

==> nui_core-1.0.4.tar.gz: lib/ui/component/nui_state_widget.dart <==
import 'package:flutter/cupertino.dart';

bool updateNUIState<T>({required String id, required T update}){
  return _NUIStateCache.updateCache<T>(id, update);
}

class _NUIStateCache{
  static Map<String, _NUIState> cache = Map();

  static void addToCache<T>(String id, _NUIState<T> state){
    cache[id] = state;
  }

  static void removeFromCache<T>(String id){
    cache.remove(id);
  }

  static bool updateCache<T>(String id, T update){
    final item = getFromCache<T>(id);
    if(item != null){
      item._refresh(update);
      return true;
    }
    return false;
  }

  static _NUIState<T>? getFromCache<T>(String id){
    final cacheItem = cache[id];
    if(cacheItem is _NUIState<T>){
      return cacheItem;
    }
    return null;
  }
}

typedef NUIStateUIListener<T> = Widget Function(T? data);
class NUIStateful<T> extends StatefulWidget {
  NUIStateful({required this.id, required this.child, required this.initial});
  final NUIStateUIListener<T> child;
  final T initial;
  final String id;
  @override
  _NUIState<T> createState() => _NUIState<T>();
}

class _NUIState<T> extends State<NUIStateful<T>> {
  T? data;

  @override
  void initState(){
    super.initState();
    data = widget.initial;
    _NUIStateCache.addToCache<T>(widget.id, this);
  }

  @override
  Widget build(BuildContext context) {
    return widget.child(data);
  }

  @override
  void dispose(){
    super.dispose();
    _NUIStateCache.removeFromCache<T>(widget.id);
  }

  void _refresh(T update){
    setState(() {
      data = update;
    });
  }
}
